==> solang-0.3.tar.gz: solang-0.3/src/common/progress-dialog.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * Copyright (C) 2009 Debarshi Ray <rishi@gnu.org>
 *
 * Solang is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Solang is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SOLANG_PROGRESS_DIALOG_H
#define SOLANG_PROGRESS_DIALOG_H

#include <glibmm.h>
#include <gtkmm.h>

#include "types.h"

namespace Solang
{

class ProgressDialog :
    public Gtk::Dialog 
{
    public:
        ProgressDialog(const ProgressObserverPtr & observer) throw();

        virtual
        ~ProgressDialog() throw();

        void
        pulse() throw();

        void
        set_pulse_step(double fraction) throw();

        void 
        set_progress_title();

        void 
        reset() throw();

    protected:
        virtual bool
        on_delete_event(GdkEventAny * event);

        virtual void
        on_response(int response_id);

        void
        on_observer_description_changed() throw();

        void
        on_progress() throw();

        ProgressObserverPtr observer_;

        Gtk::Label primaryLabel_;

        Gtk::VBox mainVBox_;

        Gtk::ProgressBar progressBar_;


    private:
};

} // namespace Solang

#endif // SOLANG_PROGRESS_DIALOG_H

==> solang-0.4.1.tar.gz: solang-0.4.1/src/common/progress-dialog.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * Copyright (C) 2010, 2009 Debarshi Ray <rishi@gnu.org>
 *
 * Solang is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Solang is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Based on code by: Alexander Larsson
 *
 * This widget was originally written in C as a part of Nautilus:
 * libnautilus-private/nautilus-progress-info.h
 */

#ifndef SOLANG_PROGRESS_DIALOG_H
#define SOLANG_PROGRESS_DIALOG_H

#include <gtkmm.h>

namespace Solang
{

class ProgressDialog :
    public Gtk::Dialog 
{
    public:
        ProgressDialog(Gtk::Window & parent) throw();

        virtual
        ~ProgressDialog() throw();

        void
        attach(Gtk::Widget & child) throw();

        void
        detach(Gtk::Widget & child) throw();

    protected:
        virtual bool
        on_delete_event(GdkEventAny * event);

    private:
        guint num_;
};

} // namespace Solang

#endif // SOLANG_PROGRESS_DIALOG_H
